==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/htdocs/view_interfaces_map_list.php <==
<? 
    include ("auth.php"); 
    adm_control_header("Interface Map List");
?>
<SCRIPT>
function change_view_type(select){
    var url = select.options[select.selectedIndex].value;
    location.href = location.href+"&view_type="+url;
    return true;
}
function change_map_url(select){
    var url = select.options[select.selectedIndex].value;
    location.href = url;
    return true;
}
</SCRIPT>
<style>
    .smallselect { font-size: 11px; }
</style>
<?

    $api = $jffnms->get("maps");

    if ($active_only=="") $active_only = 0; //active alarms

    if ($only_rootmap=="") $only_rootmap = 1; //active alarms
    
    //map
    if ($map_id=="") $map_id = 1;	
    if ($map_profile = profile("MAP")) $map_id = $map_profile; //fixed map
    
    if ($break_by_zone=="") $break_by_zone = 1;

    //view type
    if ($view_type=="") { //User had not selected any view type yet

	if ($aux = profile("VIEW_TYPE_DEFAULT"))//if its configured in the profile
	    $view_type=$aux;			//use the profile
	else					//if its not
	    $view_type = "normal";		//use the 'normal' view type
	    
	if ($events_update=="") $events_update = 1;
    } else 
	$events_update = 0;

    //source type
    if ($source=="") $source = "interfaces";
    
    if ($sound=="") $sound = profile("MAP_SOUND");
	else profile_modify_value($auth_user_id,"MAP_SOUND",$sound);

    if ($map = $api->get_all($map_id)) { 
	$register_maps = current($map);
	extract($register_maps); 
	$map_color = $color;
	adm_control_option("<b>$name</b>","_self","$REQUEST_URI&map_id=$parent&host_id=&break_by_card=0&events_update=$events_update","world.png");

	$maps = $api->get(NULL,$map_id);
	
	$maps_list["$REQUEST_URI"]="Choose";
    
	while ($rmaps = $api->fetch())
	    if ($rmaps["id"] != 1) 
		$maps_list["$REQUEST_URI&events_update=$events_update&map_id=".$rmaps["id"]."&host_id=&break_by_card=0&map_color=".$rmaps["color"]]=$rmaps["name"];

	if (count($maps_list) > 1) 
	    $select_maps = select_custom("map",$maps_list,0,"change_map_url(this)",1,0,"smallselect");
	else
	    $select_maps = "None";
    }

    adm_table_cell("| Submaps: &nbsp;".$select_maps,"left");

    adm_table_cell("| Options: &nbsp;","right");
    
    switch ($source) { 
    
	case "interfaces": 	$view_types = Array (
				    "normal"=>"Normal",
				    "normal-big"=>"Normal Big",
				    "text"=>"Text",
				    "performance"=>"Performance",
				    "graphviz"=>"GraphViz",
				    "dhtml"=>"DHTML",
				    "dhtml-big"=>"DHTML Big"
				);
				break;

	case	"maps"	:	
	case	"hosts"	:	$view_types = Array (
				    "normal"=>"Normal",
				    "normal-big"=>"Normal Big",
				    "text"=>"Text",
				    "dhtml"=>"DHTML",
				    "dhtml-big"=>"DHTML Big"
				);
				break;
    }

    $select_aux = select_custom("view_type",$view_types,$view_type,"change_view_type(this)",1,0,"smallselect");

    switch ($view_type) {
	case "normal":		$big_graph=0;
				$image = "normal.png";
				break;

	case "text":		 
				$image = "text.png";
				break;
				
	case "performance":	$break_by_host=0; 
				$break_by_card=0;
				$image = "graph.png";
				break;

	case "graphviz":	$break_by_card=0;
				$break_by_host=1; 
				$break_by_zone=0; 
				$image = "";
				break;

	case "normal-big":	$big_graph=1;
				$view_type = "normal";
				$image = "normal.png";
				break;

	case "dhtml":		$big_graph=0;
				$image = "normal.png";
				break;

	case "dhtml-big":	$big_graph=1;
				$image = "normal.png";
				$view_type="dhtml";
				break;
    }

    $options = "&map_id=$map_id&map_color=$map_color&mark_interface=$mark_interface&active_only=$active_only&break_by_card=$break_by_card&break_by_host=$break_by_host&break_by_zone=$break_by_zone&break_by_card=$break_by_card&view_type=$view_type&host_id=$host_id&sound=$sound&big_graph=$big_graph&only_rootmap=$only_rootmap&source=$source";
    $url = "view_interfaces.php?$options";

    adm_control_option("","map_viewer",$url,$image);

    adm_control_option($select_aux,"","","none","","","1%",1,"center",1);

    $pos = strpos($view_type,"-");
    if ($pos > 1) $view_type = substr($view_type,0,$pos);

    if ($no_refresh==1) 
	adm_control_option("","_self","$REQUEST_URI$options&no_refresh=0&events_update=0","refresh.png");
    else
	adm_control_option("","_self","$REQUEST_URI$options&no_refresh=1&events_update=0","refresh2.png");

    if ($active_only==1) adm_control_option("","_self","$REQUEST_URI$options&active_only=0&events_update=0","all.png");
	else adm_control_option("","_self","$REQUEST_URI$options&active_only=1&events_update=0","alert.png");

    adm_control_option("","_new",$url,"popup.png");

    if ($sound==1) adm_control_option("","_self","$REQUEST_URI$options&sound=0&events_update=0","sound.png");
	else adm_control_option("","_self","$REQUEST_URI$options&sound=1&events_update=0","nosound.png");
    
    if ($no_refresh==1)
	echo "<SCRIPT>parent.map_viewer.no_refresh = 1;</SCRIPT>\n";
    else
	echo "<SCRIPT>parent.map_viewer.location.href = '$url'+'&screen_size='+window.document.body.clientWidth;</SCRIPT>\n";
    
    if ($events_update==1) echo "<SCRIPT>parent.parent.events.location.href = 'events.php?map_id=$map_id&refresh=20';</SCRIPT>\n"; 

    adm_footer();
?>

==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/htdocs/view_interfaces_map_list.php <==
<? 
    include ("auth.php"); 
    adm_control_header("Interface Map List");
?>
<SCRIPT>

function change_view_type(select){
    var url = select.options[select.selectedIndex].value;
    location.href = location.href+"&view_type="+url;
    return true;
}

function change_map_url(select){
    var url = select.options[select.selectedIndex].value;
    location.href = url;
    return true;
}

function change_client(select) {
    var client_id = select.options[select.selectedIndex].value;
    location.href = location.href + "&no_refresh=0&events_update=1&client_id="+client_id;
    return true;
}

</SCRIPT>
<style>
    .smallselect { font-size: 11px; }
</style>
<?

    $api = $jffnms->get("maps");

    if ($active_only=="") $active_only = 0; //active alarms

    if ($only_rootmap=="") $only_rootmap = 1; //active alarms
    
    //map
    if ($map_id=="") $map_id = 1;	
    if ($map_profile = profile("MAP")) $map_id = $map_profile; //fixed map

    if (empty($client_id)) $client_id = 0;
    if ($client_id_profile = profile("CUSTOMER")) $client_id = $client_id_profile; //fixed customer
    
    if ($break_by_zone=="") $break_by_zone = 1;

    //view type
    if ($view_type=="") { //User had not selected any view type yet

	if ($aux = profile("VIEW_TYPE_DEFAULT"))//if its configured in the profile
	    $view_type=$aux;			//use the profile
	else					//if its not
	    $view_type = "normal";		//use the 'normal' view type
	    
	if ($events_update=="") $events_update = 1;
    } else 
	$events_update = 0;

    //source type
    if ($source=="") $source = "interfaces";
    
    if ($sound=="") $sound = profile("MAP_SOUND");
	else profile_modify_value($auth_user_id,"MAP_SOUND",$sound);

    if ($map = $api->get_all($map_id)) { 
	$register_maps = current($map);
	extract($register_maps); 
	$map_color = $color;
	adm_control_option("<b>$name</b>","_self","$REQUEST_URI&map_id=$parent&host_id=&break_by_card=0&events_update=$events_update","world.png");

	$maps = $api->get(NULL,$map_id);
	
	$maps_list["$REQUEST_URI"]="Choose Map";
    
	while ($rmaps = $api->fetch())
	    if ($rmaps["id"] != 1) 
		$maps_list["$REQUEST_URI&events_update=$events_update&map_id=".$rmaps["id"]."&host_id=&break_by_card=0&map_color=".$rmaps["color"]]=$rmaps["name"];

	if (count($maps_list) > 1) 
	    $select_maps = select_custom("map",$maps_list,0,"change_map_url(this)",1,0,"smallselect");
	else
	    $select_maps = "None";
    }
    
    adm_table_cell("| Submaps: &nbsp;".$select_maps."&nbsp;".$client_select,"left");

    if ($client_id_profile==0)
	adm_table_cell ("| Customers: &nbsp;".select_clients("", $client_id, 1, array(0=>"All"),"change_client(this)"),"left");

    adm_table_cell("| Options: &nbsp;","right");
    
    switch ($source) { 
    
	case "interfaces": 	$view_types = Array (
				    "normal"=>"Normal",
				    "normal-big"=>"Normal Big",
				    "text"=>"Text",
				    "performance"=>"Performance",
				    "graphviz"=>"GraphViz",
				    "dhtml"=>"DHTML",
				    "dhtml-big"=>"DHTML Big"
				);
				break;

	case	"maps"	:	
	case	"hosts"	:	$view_types = Array (
				    "normal"=>"Normal",
				    "normal-big"=>"Normal Big",
				    "text"=>"Text",
				    "dhtml"=>"DHTML",
				    "dhtml-big"=>"DHTML Big"
				);
				break;
    }

    $select_aux = select_custom("view_type",$view_types,$view_type,"change_view_type(this)",1,0,"smallselect");

    switch ($view_type) {
	case "normal":		$big_graph=0;
				$image = "normal.png";
				break;

	case "text":		 
				$image = "text.png";
				break;
				
	case "performance":	$break_by_host=0; 
				$break_by_card=0;
				$image = "graph.png";
				break;

	case "graphviz":	$break_by_card=0;
				$break_by_host=1; 
				$break_by_zone=0; 
				$image = "";
				break;

	case "normal-big":	$big_graph=1;
				$view_type = "normal";
				$image = "normal.png";
				break;

	case "dhtml":		$big_graph=0;
				$image = "normal.png";
				break;

	case "dhtml-big":	$big_graph=1;
				$image = "normal.png";
				$view_type="dhtml";
				break;
    }

    $options = "&map_id=$map_id&map_color=$map_color&mark_interface=$mark_interface&active_only=$active_only&break_by_card=$break_by_card&break_by_host=$break_by_host&break_by_zone=$break_by_zone&break_by_card=$break_by_card&view_type=$view_type&host_id=$host_id&sound=$sound&big_graph=$big_graph&only_rootmap=$only_rootmap&source=$source&client_id=$client_id";
    $url = "view_interfaces.php?$options";

    adm_control_option("","map_viewer",$url,$image);

    adm_control_option($select_aux,"","","none","","","1%",1,"center",1);

    $pos = strpos($view_type,"-");
    if ($pos > 1) $view_type = substr($view_type,0,$pos);

    if ($no_refresh==1) 
	adm_control_option("","_self","$REQUEST_URI$options&no_refresh=0&events_update=0","refresh.png");
    else
	adm_control_option("","_self","$REQUEST_URI$options&no_refresh=1&events_update=0","refresh2.png");

    if ($active_only==1) adm_control_option("","_self","$REQUEST_URI$options&active_only=0&events_update=0","all.png");
	else adm_control_option("","_self","$REQUEST_URI$options&active_only=1&events_update=0","alert.png");

    adm_control_option("","_new",$url,"popup.png");

    if ($sound==1) adm_control_option("","_self","$REQUEST_URI$options&sound=0&events_update=0","sound.png");
	else adm_control_option("","_self","$REQUEST_URI$options&sound=1&events_update=0","nosound.png");
    
    if ($no_refresh==1)
	echo "<SCRIPT>parent.map_viewer.no_refresh = 1;</SCRIPT>\n";
    else
	echo "<SCRIPT>parent.map_viewer.location.href = '$url'+'&screen_size='+window.document.body.clientWidth;</SCRIPT>\n";
    
    if ($events_update==1) echo "<SCRIPT>parent.parent.events.location.href = 'events.php?map_id=$map_id&refresh=20&client_id=$client_id';</SCRIPT>\n"; 

    adm_footer();
?>
